/***************************************************************************
 *   Copyright (C) 2004 by Jens Luetkens                                   *
 *   j.luetkens@limitland.de                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <qcheckbox.h>
#include <qspinbox.h>
#include <qcombobox.h>
#include <qwhatsthis.h>

#include <kcolorbutton.h>

#include <kconfig.h>
#include <klocale.h>
#include <kglobal.h>

#include "config.h"
#include "configdialog.h"

//
// Constructor
//
RidgeConfig::RidgeConfig(KConfig* config, QWidget* parent)
    : QObject(parent), m_config(0), m_dialog(0)
{
    // create the configuration object
    m_config = new KConfig("kwinridgerc");
    KGlobal::locale()->insertCatalogue("kwin_ridge_config");

    // create and show the configuration dialog
    m_dialog = new ConfigDialog(parent);
    m_dialog->show();

    // load the configuration
    load(config);

    // setup the connections
    connect(m_dialog->useBorder, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->sizeBorder, SIGNAL(valueChanged(int)),
            this, SIGNAL(changed()));
			
    connect(m_dialog->useOffset, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->sizeOffset, SIGNAL(valueChanged(int)),
            this, SIGNAL(changed()));

    connect(m_dialog->useDecoration, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->themeDecoration, SIGNAL(activated(int)),
            this, SIGNAL(changed()));

    connect(m_dialog->useOutline, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->colorActive, SIGNAL(changed(const QColor &)),
            this, SIGNAL(changed()));
    connect(m_dialog->colorInactive, SIGNAL(changed(const QColor &)),
            this, SIGNAL(changed()));

}

//
// Destructor
//
RidgeConfig::~RidgeConfig()
{
    if (m_dialog) delete m_dialog;
    if (m_config) delete m_config;
}

//
// load(KConfig*)
//
void RidgeConfig::load(KConfig*)
{

	QColor defaultAColor(74,84,95);
	QColor defaultIColor(58,67,75);

    m_config->setGroup("General");

    bool useBorder = m_config->readBoolEntry("hasBorder", true);
    m_dialog->useBorder->setChecked(useBorder);
    int borderSize = m_config->readNumEntry("borderSize", 3);
    m_dialog->sizeBorder->setValue(borderSize);

    bool useOffset = m_config->readBoolEntry("hasOffset", true);
    m_dialog->useOffset->setChecked(useOffset);
    int offsetSize = m_config->readNumEntry("offsetSize", 5);
    m_dialog->sizeOffset->setValue(offsetSize);

    bool useDecoration = m_config->readBoolEntry("hasDecoration", true);
    m_dialog->useDecoration->setChecked(useDecoration);
	QString decorationTheme = m_config->readEntry("decorationTheme", "Gradient");
	m_dialog->themeDecoration->setCurrentText(decorationTheme);

    bool useOutline = m_config->readBoolEntry("hasOutline", true);
    m_dialog->useOutline->setChecked(useOutline);
	QColor outlineAColor = m_config->readColorEntry("outlineAColor", &defaultAColor);
	m_dialog->colorActive->setColor(outlineAColor);
	QColor outlineIColor = m_config->readColorEntry("outlineIColor", &defaultIColor);
	m_dialog->colorInactive->setColor(outlineIColor);

}

//
// save(KConfig*)
//
void RidgeConfig::save(KConfig*)
{
    m_config->setGroup("General");

    m_config->writeEntry("hasBorder", m_dialog->useBorder->isChecked() );
    m_config->writeEntry("borderSize", m_dialog->sizeBorder->value() );

    m_config->writeEntry("hasOffset", m_dialog->useOffset->isChecked() );
    m_config->writeEntry("offsetSize", m_dialog->sizeOffset->value() );

    m_config->writeEntry("hasDecoration", m_dialog->useDecoration->isChecked() );
    m_config->writeEntry("decorationTheme", m_dialog->themeDecoration->currentText() );

    m_config->writeEntry("hasOutline", m_dialog->useOutline->isChecked() );
	m_config->writeEntry("outlineAColor", m_dialog->colorActive->color());
	m_config->writeEntry("outlineIColor", m_dialog->colorInactive->color());

    m_config->sync();
}

//
// defaults()
//
void RidgeConfig::defaults()
{

    m_dialog->useBorder->setChecked(true);
    m_dialog->sizeBorder->setValue(3);

    m_dialog->useOffset->setChecked(true);
    m_dialog->sizeOffset->setValue(4);

    m_dialog->useDecoration->setChecked(true);
    m_dialog->themeDecoration->setCurrentText("Gradient");

    m_dialog->useOutline->setChecked(true);
    m_dialog->colorActive->setColor(QColor(74,84,95));
    m_dialog->colorInactive->setColor(QColor(58,67,75));

}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

extern "C"
{
    QObject* allocate_config(KConfig* config, QWidget* parent) {
        return (new RidgeConfig(config, parent));
    }
}

//#include "config.moc"
